@@ -66,7 +66,6 @@ typedef enum {
 GType gis_driver_get_type (void);
 
 GisAssistant *gis_driver_get_assistant (GisDriver *driver);
-void gis_driver_locale_changed (GisDriver *driver);
 
 void gis_driver_set_user_permissions (GisDriver   *driver,
                                       ActUser     *user,
@@ -82,9 +81,10 @@ void gis_driver_set_account_mode (GisDriver     *driver,
 UmAccountMode gis_driver_get_account_mode (GisDriver *driver);
 
 void gis_driver_set_user_language (GisDriver   *driver,
-                                   const gchar *lang_id);
+                                   const gchar *lang_id,
+                                   gboolean     update_locale);
 
-const gchar *gis_driver_get_user_language (GisDriver   *driver);
+const gchar *gis_driver_get_user_language (GisDriver *driver);
 
 void gis_driver_set_username (GisDriver   *driver,
                               const gchar *username);
